<?php

use App\Http\Controllers\AppSettingsController;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;
//Controllers
use App\Http\Controllers\BrandController;
use App\Http\Controllers\CatalogController;
use App\Http\Controllers\CategoryController;
use App\Http\Controllers\DeliveryTypeController;
use App\Http\Controllers\GeoFinseingController;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\NotificationController;
use App\Http\Controllers\OrdersController;
use App\Http\Controllers\SubCategoryController;
use App\Http\Controllers\ProductsController;
use App\Http\Controllers\SliderController;
use App\Http\Controllers\UserAdressController;
//Livewire
use App\Http\Livewire\CategoryDropDown;



/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/


Auth::routes();

Route::group(['middleware' => 'auth'], function () {
        Route::group(['prefix' => 'dashboard'], function () {
            Route::get('',[HomeController::class, 'root'])->name('home.index');

            Route::group(['prefix' => 'delivery'], function () {
                Route::get('',[DeliveryTypeController::class, 'home'])->name('delivery.home');
                Route::get('edit/{id}',[DeliveryTypeController::class, 'edit'])->name('delivery-types.edit');
                Route::post('update/{id}',[DeliveryTypeController::class, 'update'])->name('delivery-types.update');
                Route::get('create',[DeliveryTypeController::class, 'create'])->name('delivery.create');
                Route::post('store',[DeliveryTypeController::class, 'store'])->name('delivery.create.post');
                Route::post('destroy/{id}',[DeliveryTypeController::class, 'destroy'])->name('delivery-types.destroy');
            });


            Route::group(['prefix' => 'slider'], function () {
                Route::get('',[SliderController::class, 'home'])->name('slider.home');
                Route::get('edit/{id}',[SliderController::class, 'edit'])->name('slider.edit');
                Route::post('update/{id}',[SliderController::class, 'update'])->name('slider.update');
                Route::get('create',[SliderController::class, 'create'])->name('slider.create');
                Route::post('store',[SliderController::class, 'store'])->name('slider.create.post');
                Route::post('destroy/{id}',[SliderController::class, 'destroy'])->name('slider.destroy');
            });


            Route::group(['prefix' => 'version'], function () {
                Route::get('',[AppSettingsController::class, 'home'])->name('version.home');
                Route::get('edit/{id}',[AppSettingsController::class, 'edit'])->name('version.edit');
                Route::post('update/{id}',[AppSettingsController::class, 'update'])->name('version.update');
                Route::get('create',[AppSettingsController::class, 'create'])->name('version.create');
                Route::post('store',[AppSettingsController::class, 'store'])->name('version.create.post');
                Route::post('destroy/{id}',[AppSettingsController::class, 'destroy'])->name('version.destroy');
            });


            Route::group(['prefix' => 'notification'], function () {
                Route::get('',[NotificationController::class, 'home'])->name('notification.home');
                Route::get('user/{id}',[NotificationController::class, 'userid'])->name('notification.userid');
                Route::post('user',[NotificationController::class, 'send'])->name('notification.user.all');
            });


            Route::group(['prefix' => 'geo'], function () {
                Route::get('',[GeoFinseingController::class, 'home'])->name('geo.home');
                Route::get('edit/{id}',[GeoFinseingController::class, 'edit'])->name('geo.edit');
                Route::post('update/{id}',[GeoFinseingController::class, 'update'])->name('geo.update');
                Route::get('create',[GeoFinseingController::class, 'create'])->name('geo.create');
                Route::post('store',[GeoFinseingController::class, 'store'])->name('geo.create.post');
                Route::post('destroy/{id}',[GeoFinseingController::class, 'destroy'])->name('geo.destroy');
            });


            Route::group(['prefix' => 'users'], function () {
                Route::get('',[UserAdressController::class, 'getUsers'])->name('users.list');
            });

            Route::group(['prefix' => 'orders'], function () {
                Route::get('user/{userid}',[OrdersController::class, 'getUserId'])->name('order.user.list');
            });

            Route::group(['prefix' => 'invoices'], function () {
                Route::get('',[OrdersController::class, 'getUserInvoices'])->name('invoices.user.list');
                Route::get('id/{order_id}',[OrdersController::class, 'getUserInvoicesId'])->name('invoices.order.id');
            });

        });
    });




Route::get('/', [App\Http\Controllers\HomeController::class, 'root']);
Route::get('{any}', [App\Http\Controllers\HomeController::class, 'index']);
//Language Translation
Route::get('index/{locale}', [App\Http\Controllers\HomeController::class, 'lang']);
Route::post('/formsubmit', [App\Http\Controllers\HomeController::class, 'FormSubmit'])->name('FormSubmit');
//brands
Route::get('brands/view',[BrandController::class, 'AllBrands'])->name('all.brands');
Route::post('/brands/add', [BrandController::class, 'AddBrand'])->name('store.brands');
Route::get('/delete/brand/{id}', [BrandController::class, 'SoftDelete']);
Route::get('/brand/edit/{id}', [BrandController::class, 'Edit']);
Route::post('/brand/update/{id}', [BrandController::class, 'Update']);

//category
Route::get('categories/view',[CategoryController::class, 'Allcategories'])->name('all.categories');
Route::post('/categories/add', [CategoryController::class, 'AddCat'])->name('store.category');
Route::get('/delete/category/{id}', [CategoryController::class, 'SoftDelete']);
Route::get('/category/edit/{id}', [CategoryController::class, 'Edit']);
Route::post('/category/update/{id}', [CategoryController::class, 'Update']);

//sub category
Route::get('subcategories/view',[SubCategoryController::class, 'AllSubcategories'])->name('all.subcategories');
Route::post('subcategories/add', [SubCategoryController::class, 'AddSubCat'])->name('store.subcategory');
Route::get('/delete/subcategory/{id}', [SubCategoryController::class, 'SoftDelete']);
Route::get('/subcategory/edit/{id}', [SubCategoryController::class, 'Edit']);
Route::post('/subcategory/update/{id}', [SubCategoryController::class, 'Update']);

//catalogs
Route::get('catalogs/view',[CatalogController::class, 'Allcatalogs'])->name('all.catalogs');
Route::post('catalog/add', [CatalogController::class, 'Addcatalog'])->name('store.catalogs');
Route::get('/delete/catalog/{id}', [CatalogController::class, 'SoftDelete']);

//products
Route::get('products/view',[ProductsController::class, 'Allproducts'])->name('all.products');
Route::get('/products/add', [ProductsController::class, 'Addproducts'])->name('add.products');
Route::post('products/save', [ProductsController::class, 'Saveproducts'])->name('store.products');
Route::get('/delete/product/{id}', [ProductsController::class, 'SoftDelete']);
Route::get('/product/edit/{id}', [ProductsController::class, 'Edit']);
Route::post('/product/update/{id}', [ProductsController::class, 'Updateproduct']);
